@@ -1,4 +1,6 @@
 use crate::{CoordFloat, CoordNum, LineString, Point, Rect, Triangle};
+use alloc::vec;
+use alloc::vec::Vec;
 use num_traits::{Float, Signed};
 
 #[cfg(any(feature = "approx", test))]
@@ -10,7 +12,7 @@ use approx::{AbsDiffEq, RelativeEq};
 /// [`LineString`]. It may contain zero or more holes (_interior rings_), also
 /// represented by `LineString`s.
 ///
-/// A `Polygon` can be created with the [`Polygon::new`] constructor or the [`polygon!`] macro.
+/// A `Polygon` can be created with the [`Polygon::new`] constructor or the [`polygon!`][`crate::polygon!`] macro.
 ///
 /// # Semantics
 ///
@@ -20,7 +22,7 @@ use approx::{AbsDiffEq, RelativeEq};
 /// boundary).
 ///
 /// The `Polygon` structure guarantees that all exterior and interior rings will
-/// be _closed_, such that the first and last `Coordinate` of each ring has
+/// be _closed_, such that the first and last `Coord` of each ring has
 /// the same value.
 ///
 /// # Validity
@@ -59,9 +61,9 @@ use approx::{AbsDiffEq, RelativeEq};
 /// Some APIs on `Polygon` result in a closing operation on a `LineString`. The
 /// operation is as follows:
 ///
-/// If a `LineString`’s first and last `Coordinate` have different values, a
-/// new `Coordinate` will be appended to the `LineString` with a value equal to
-/// the first `Coordinate`.
+/// If a `LineString`’s first and last `Coord` have different values, a
+/// new `Coord` will be appended to the `LineString` with a value equal to
+/// the first `Coord`.
 ///
 /// [`LineString`]: line_string/struct.LineString.html
 #[derive(Eq, PartialEq, Clone, Debug, Hash)]
@@ -109,7 +111,7 @@ impl<T: CoordNum> Polygon<T> {
     /// );
     /// ```
     ///
-    /// If the first and last `Coordinate`s of the exterior or interior
+    /// If the first and last `Coord`s of the exterior or interior
     /// `LineString`s no longer match, those `LineString`s [will be closed]:
     ///
     /// ```
@@ -214,7 +216,7 @@ impl<T: CoordNum> Polygon<T> {
     /// );
     /// ```
     ///
-    /// If the first and last `Coordinate`s of the exterior `LineString` no
+    /// If the first and last `Coord`s of the exterior `LineString` no
     /// longer match, the `LineString` [will be closed]:
     ///
     /// ```
@@ -305,7 +307,7 @@ impl<T: CoordNum> Polygon<T> {
     /// );
     /// ```
     ///
-    /// If the first and last `Coordinate`s of any interior `LineString` no
+    /// If the first and last `Coord`s of any interior `LineString` no
     /// longer match, those `LineString`s [will be closed]:
     ///
     /// ```
@@ -543,7 +545,12 @@ impl<T: AbsDiffEq<Epsilon = T> + CoordNum> AbsDiffEq for Polygon<T> {
     }
 }
 
-#[cfg(any(feature = "rstar_0_8", feature = "rstar_0_9"))]
+#[cfg(any(
+    feature = "rstar_0_8",
+    feature = "rstar_0_9",
+    feature = "rstar_0_10",
+    feature = "rstar_0_11"
+))]
 macro_rules! impl_rstar_polygon {
     ($rstar:ident) => {
         impl<T> $rstar::RTreeObject for Polygon<T>
@@ -564,3 +571,9 @@ impl_rstar_polygon!(rstar_0_8);
 
 #[cfg(feature = "rstar_0_9")]
 impl_rstar_polygon!(rstar_0_9);
+
+#[cfg(feature = "rstar_0_10")]
+impl_rstar_polygon!(rstar_0_10);
+
+#[cfg(feature = "rstar_0_11")]
+impl_rstar_polygon!(rstar_0_11);
